@@ -1,8 +1,6 @@
 package Moose::Exception::RequiredMethodsNotImplementedByClass;
-BEGIN {
-  $Moose::Exception::RequiredMethodsNotImplementedByClass::AUTHORITY = 'cpan:STEVAN';
-}
-$Moose::Exception::RequiredMethodsNotImplementedByClass::VERSION = '2.1204';
+our $VERSION = '2.2201';
+
 use Moose;
 extends 'Moose::Exception';
 with 'Moose::Exception::Role::Class', 'Moose::Exception::Role::Role';
@@ -29,4 +27,5 @@ sub _build_message {
         . "to be implemented by '$class_name'";
 }
 
+__PACKAGE__->meta->make_immutable;
 1;
